@@ -143,7 +143,7 @@ pref("keyword.URL", "chrome://browser-region/locale/region.properties");
 
 pref("general.useragent.locale", "en-US");
 pref("general.skins.selectedSkin", "classic/1.0");
-pref("general.useragent.extra.firefox", "Firefox/3.6.3");
+pref("general.useragent.extra.firefox", "Firefox/3.6.4");
 
 pref("general.smoothScroll", false);
 //@line 190 "/builds/slave/linux_build/build/browser/app/profile/firefox.js"
@@ -782,3 +782,12 @@ pref("geo.wifi.uri", "https://www.google.com/loc/json");
 pref("toolbar.customization.usesheet", false);
 //@line 911 "/builds/slave/linux_build/build/browser/app/profile/firefox.js"
 
+// Whitelist the test plugin, Flash, Silverlight, and QuickTime
+ 
+pref("dom.ipc.plugins.enabled.libnptest.so", true);
+//@line 921 "/builds/slave/linux_build/build/browser/app/profile/firefox.js"
+pref("dom.ipc.plugins.enabled.libflashplayer.so", true);
+//@line 923 "/builds/slave/linux_build/build/browser/app/profile/firefox.js"
+
+pref("dom.ipc.plugins.enabled", false);
+
